@@ -1,3 +1,4 @@
+from os import environ
 from pathlib import Path
 from typing import TYPE_CHECKING
 
@@ -17,14 +18,14 @@ class Settings(BaseSettings):
     OUGHT_INFERENCE_URL: AnyHttpUrl = "https://inference.elicit.org"
     GOLD_STANDARDS_CSV_PATH: str = "gold_standards/gold_standards.csv"
     GS_QUOTE_FOUND_THRESHOLD: float = 0.75
-    OUGHT_ICE_DIR: Path = Path.home() / ".ought-ice"
-
-    class Config:
-        env_file = ".env"
-        env_file_encoding = "utf-8"
 
 
-settings = Settings()
+OUGHT_ICE_DIR = Path(environ.get("OUGHT_ICE_DIR", Path.home() / ".ought-ice"))
 
-CACHE_DIR = settings.OUGHT_ICE_DIR / "cache"
+_env_path = OUGHT_ICE_DIR / ".env"
+settings = Settings(
+    _env_file=_env_path if _env_path.exists() else None, _env_file_encoding="utf-8"
+)
+
+CACHE_DIR = OUGHT_ICE_DIR / "cache"
 CACHE_DIR.mkdir(parents=True, exist_ok=True)
